@@ -70,7 +70,13 @@ TEST_XML(dom_attr_set_value, "<node/>")
 	CHECK(node.append_attribute(STR("attr8")).set_value(true));
 	CHECK(!xml_attribute().set_value(true));
 
-	CHECK_NODE(node, STR("<node attr1=\"v1\" attr2=\"-2147483647\" attr3=\"-2147483648\" attr4=\"4294967295\" attr5=\"4294967294\" attr6=\"0.5\" attr7=\"0.25\" attr8=\"true\"/>"));
+	CHECK(node.append_attribute(STR("attr9")).set_value(STR("v2"), 2));
+	CHECK(!xml_attribute().set_value(STR("v2")));
+
+	CHECK(node.append_attribute(STR("attr10")).set_value(STR("v3foobar"), 2));
+	CHECK(!xml_attribute().set_value(STR("v3")));
+
+	CHECK_NODE(node, STR("<node attr1=\"v1\" attr2=\"-2147483647\" attr3=\"-2147483648\" attr4=\"4294967295\" attr5=\"4294967294\" attr6=\"0.5\" attr7=\"0.25\" attr8=\"true\" attr9=\"v2\" attr10=\"v3\"/>"));
 }
 
 #if LONG_MAX > 2147483647
@@ -209,6 +215,24 @@ TEST_XML(dom_node_set_value, "<node>text</node>")
 	CHECK_NODE(doc, STR("<node>no text</node>"));
 }
 
+TEST_XML(dom_node_set_value_partially_with_size, "<node>text</node>")
+{
+	CHECK(doc.child(STR("node")).first_child().set_value(STR("no text"), 2));
+	CHECK(!doc.child(STR("node")).set_value(STR("no text"), 2));
+	CHECK(!xml_node().set_value(STR("no text"), 2));
+
+	CHECK_NODE(doc, STR("<node>no</node>"));
+}
+
+TEST_XML(dom_node_set_value_with_size, "<node>text</node>")
+{
+	CHECK(doc.child(STR("node")).first_child().set_value(STR("no text"), 7));
+	CHECK(!doc.child(STR("node")).set_value(STR("no text"), 7));
+	CHECK(!xml_node().set_value(STR("no text"), 7));
+
+	CHECK_NODE(doc, STR("<node>no text</node>"));
+}
+
 TEST_XML(dom_node_set_value_allocated, "<node>text</node>")
 {
 	CHECK(doc.child(STR("node")).first_child().set_value(STR("no text")));
